"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Route = exports.Router = exports.Method = void 0;
exports.Method = {
    GET: 'GET',
    POST: 'POST',
    PUT: 'PUT',
    DELETE: 'DELETE',
};
var Router = /** @class */ (function () {
    function Router() {
        this.routes = {};
        this.routes[exports.Method.GET] = [];
    }
    Router.prototype.registerRoutes = function (callback) {
        callback(this);
    };
    Router.prototype.dispatch = function (req, res) {
        if (req.method === undefined) {
            res.statusCode = 404;
            res.end('404 Not Found');
            return;
        }
        var potentialRoutes = this.routes[req.method].filter(function (route) { return route.isMatch(req); });
        if (potentialRoutes.length > 0) {
            potentialRoutes[0].action(req, res);
            return;
        }
        res.statusCode = 404;
        res.end('404 Not Found');
    };
    Router.prototype.get = function (path, action) {
        this.routes[exports.Method.GET].push(new Route(exports.Method.GET, path, action));
    };
    return Router;
}());
exports.Router = Router;
var Route = /** @class */ (function () {
    function Route(method, path, action) {
        this.method = method;
        this.path = path;
        this.action = action;
        this.regex = this.buildRegex();
    }
    Route.prototype.isMatch = function (req) {
        if (req.url === undefined)
            return false;
        console.info(this.regex, req.url, this.regex.test(req.url));
        return this.regex.test(req.url);
    };
    Route.prototype.buildRegex = function () {
        var segments = this.path.split('/')
            .map(function (segment) {
            if (segment.charAt(0) === '{' && segment.charAt(segment.length - 1) === '}') {
                return "(?<" + segment.slice(1, -1) + ">[A-Za-z0-9]+)";
            }
            return segment;
        })
            .join('/');
        return new RegExp("^" + segments + "$");
    };
    return Route;
}());
exports.Route = Route;
